@@ -1,9 +1,9 @@
 package Net::DNS::SEC::RSA;
 
 #
-# $Id: RSA.pm 1621 2018-01-26 14:18:58Z willem $
+# $Id: RSA.pm 1658 2018-03-29 15:07:50Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1621 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1658 $)[1];
 
 
 =head1 NAME
@@ -29,14 +29,14 @@ generation and verification procedures.
 
     $signature = Net::DNS::SEC::RSA->sign( $sigdata, $private );
 
-Generates the wire-format binary signature from the binary sigdata
+Generates the wire-format signature from the sigdata octet string
 and the appropriate private key object.
 
 =head2 verify
 
     $validated = Net::DNS::SEC::RSA->verify( $sigdata, $keyrr, $sigbin );
 
-Verifies the signature over the binary sigdata using the specified
+Verifies the signature over the sigdata octet string using the specified
 public key resource record.
 
 =cut
@@ -51,11 +51,11 @@ use MIME::Base64;
 eval { require Digest::MD5 };		## deprecated ##
 
 my %RSA = (
-	1  => ['MD5',	 'Digest::MD5'],
-	5  => ['SHA1',	 'Digest::SHA'],
-	7  => ['SHA1',	 'Digest::SHA'],
-	8  => ['SHA256', 'Digest::SHA', 256],
-	10 => ['SHA512', 'Digest::SHA', 512],
+	1  => [4,	'Digest::MD5'],
+	5  => [64,	'Digest::SHA'],
+	7  => [64,	'Digest::SHA'],
+	8  => [672,	'Digest::SHA', 256],
+	10 => [674,	'Digest::SHA', 512],
 	);
 
 
@@ -63,12 +63,11 @@ sub sign {
 	my ( $class, $sigdata, $private ) = @_;
 
 	my $algorithm = $private->algorithm;			# digest sigdata
-	my ( $mnemonic, $object, @param ) = @{$RSA{$algorithm} || []};
+	my ( $nid, $object, @param ) = @{$RSA{$algorithm} || []};
 	die 'public key not RSA' unless $object;
 	my $hash = $object->new(@param);
 	$hash->add($sigdata);
 
-	my $nid = Net::DNS::SEC::libcrypto::get_NID($mnemonic);
 	my $rsa = Net::DNS::SEC::libcrypto::RSA_new();
 
 	my ( $n, $e, $d, $p, $q ) = map decode_base64( $private->$_ ),
@@ -76,7 +75,6 @@ sub sign {
 
 	Net::DNS::SEC::libcrypto::RSA_set0_factors( $rsa, $p, $q );
 	Net::DNS::SEC::libcrypto::RSA_set0_key( $rsa, $n, $e, $d );
-	$d = $e;						# destroy private exponent
 
 	my $sig = Net::DNS::SEC::libcrypto::RSA_sign( $nid, $hash->digest, $rsa );
 
@@ -89,14 +87,13 @@ sub verify {
 	my ( $class, $sigdata, $keyrr, $sigbin ) = @_;
 
 	my $algorithm = $keyrr->algorithm;			# digest sigdata
-	my ( $mnemonic, $object, @param ) = @{$RSA{$algorithm} || []};
+	my ( $nid, $object, @param ) = @{$RSA{$algorithm} || []};
 	die 'public key not RSA' unless $object;
 	my $hash = $object->new(@param);
 	$hash->add($sigdata);
 
 	return unless $sigbin;
 
-	my $nid = Net::DNS::SEC::libcrypto::get_NID($mnemonic);
 	my $rsa = Net::DNS::SEC::libcrypto::RSA_new();
 
 	my $keybin = $keyrr->keybin;				# public key
